@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c 5345 2006-12-07 23:33:28Z paolo $
+ * $Id: gedit-commands-file.c 5437 2007-01-09 23:09:57Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1081,30 +1081,14 @@ _gedit_cmd_file_save_all (GtkAction   *action,
 
 /* File revert */
 static void
-revert_dialog_response_cb (GtkDialog     *dialog,
-			   gint           response_id,
-			   GeditWindow   *window)
+do_revert (GeditWindow *window,
+	   GeditTab    *tab)
 {
-	GeditTab *tab;
 	GeditDocument *doc;
 	gchar *docname;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	/* FIXME: we are relying on the fact that the dialog is
-	   modal so the active tab can't be changed...
-	   not very nice - Paolo (Oct 11, 2005) */
-	tab = gedit_window_get_active_tab (window);
-	if (tab == NULL)
-		return;
-
-	if (response_id != GTK_RESPONSE_OK)
-	{
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-
-		return;
-	}
-
 	doc = gedit_tab_get_document (tab);
 	docname = gedit_document_get_short_name_for_display (doc);
 
@@ -1114,11 +1098,34 @@ revert_dialog_response_cb (GtkDialog     *dialog,
 				       docname);
 
 	g_free (docname);
-	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	_gedit_tab_revert (tab);
 }
 
+static void
+revert_dialog_response_cb (GtkDialog   *dialog,
+			   gint         response_id,
+			   GeditWindow *window)
+{
+	GeditTab *tab;
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	/* FIXME: we are relying on the fact that the dialog is
+	   modal so the active tab can't be changed...
+	   not very nice - Paolo (Oct 11, 2005) */
+	tab = gedit_window_get_active_tab (window);
+	if (tab == NULL)
+		return;
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (response_id == GTK_RESPONSE_OK)
+	{
+		do_revert (window, tab);
+	}
+}
+
 static GtkWidget *
 revert_dialog (GeditWindow   *window,
 	       GeditDocument *doc)
@@ -1242,13 +1249,26 @@ void
 _gedit_cmd_file_revert (GtkAction   *action,
 		       GeditWindow *window)
 {
+	GeditTab       *tab;
 	GeditDocument  *doc;
 	GtkWidget      *dialog;
 	GtkWindowGroup *wg;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	doc = gedit_window_get_active_document (window);
+	tab = gedit_window_get_active_tab (window);
+	g_return_if_fail (tab != NULL);
+
+	/* If we are already displaying a notification
+	 * reverting will drop local modifications, do
+	 * not bug the user further */
+	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION)
+	{
+		do_revert (window, tab);
+		return;
+	}
+
+	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (doc != NULL);
 	g_return_if_fail (!gedit_document_is_untitled (doc));
 
